.. py:currentmodule:: rubin_sim.maf

.. _maf-api:

=======
MAF API
=======


.. toctree::

    Batches <maf-api-batches>
    Databases (db) <maf-api-db>
    Maps <maf-api-maps>
    Maf Contrib <maf-api-maf-contrib>
    Metrics <maf-api-metrics>
    MetricBundles <maf-api-metricbundles>
    Plots <maf-api-plots>
    Run Comparison <maf-api-run-comparison>
    Slicers <maf-api-slicers>
    Stackers <maf-api-stackers>
    Utils <maf-api-utils>